==> 0.1.3.tar.gz: lib/widget/vgk-card-horizontal-widget/vgk-card-horizontal-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-card-horizontal-widget/vgk-card-horizontal-content-widget.dart';

class VgkCardHorizontalWidget extends StatefulWidget {
  const VgkCardHorizontalWidget({
    Key key,
    this.mainScreenAnimationController,
    this.mainScreenAnimation,
    this.data,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final List<VgkCardHorizontalDetailModel> data;
  @override
  _VgkCardHorizontalWidgetState createState() =>
      _VgkCardHorizontalWidgetState();
}

class _VgkCardHorizontalWidgetState extends State<VgkCardHorizontalWidget>
    with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkprogamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkprogamingTheme.transform(widget.mainScreenAnimation),
            child: Container(
              height: 150,
              width: double.infinity,
              child: ListView.builder(
                padding: VgkprogamingTheme.edgeInsetsPaddingSmall,
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkprogamingTheme.animationOption(animationController);
                  animationController.forward();
                  return VgkCardHorizontalContentWidget(
                    data: widget.data[index],
                    animationController: animationController,
                    animation: animation,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

==> 0.9.5.tar.gz: lib/widget/vgk-card-horizontal-widget/vgk-card-horizontal-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-card-horizontal-widget/vgk-card-horizontal-content-widget.dart';

class VgkCardHorizontalWidget extends StatefulWidget {
  const VgkCardHorizontalWidget({
    Key key,
    this.mainScreenAnimationController,
    this.mainScreenAnimation,
    this.data,
    this.primaryColor,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final List<VgkCardHorizontalDetailModel> data;
  final String primaryColor;
  @override
  _VgkCardHorizontalWidgetState createState() =>
      _VgkCardHorizontalWidgetState();
}

class _VgkCardHorizontalWidgetState extends State<VgkCardHorizontalWidget>
    with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: Container(
              height: 150,
              width: double.infinity,
              child: ListView.builder(
                padding: VgkProGamingTheme.edgeInsetsPaddingSmall,
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return VgkCardHorizontalContentWidget(
                    data: widget.data[index],
                    animationController: animationController,
                    animation: animation,
                    primaryColor: widget.primaryColor,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}
